@@ -1,4 +1,4 @@
-from frontegg.common.frontegg_config import FronteggConfig
+from frontegg.common import FronteggConfig
 import requests
 from frontegg.helpers.frontegg_urls import frontegg_urls
 import arrow
